@@ -13,6 +13,9 @@ url_new = "https://yiyan.baidu.com/eb/session/new"
 url_new_text = "https://yiyan.baidu.com/eb/chat/new"
 url_check = "https://yiyan.baidu.com/eb/chat/check"
 
+
+abs_path = os.path.dirname(os.path.realpath(sys.argv[0])) + '/'
+
 """
     错误类
     code:
@@ -81,10 +84,7 @@ class WenXinBot:
     """
     def initSelenium(self, headless=True, debug = False) -> bool:
         # 启动代理
-        # 检测系统是windows还是linux
-        if sys.platform == "linux":
-            server_proxy = Server(r'src/wenxin/browsermob-proxy-2.1.4/bin/browsermob-proxy.bat')
-        else: server_proxy = Server(r'src\wenxin\browsermob-proxy-2.1.4\bin\browsermob-proxy.bat')
+        server_proxy = Server(abs_path+'wenxin/browsermob-proxy-2.1.4/bin/browsermob-proxy.bat')
         server_proxy.start()
         self.seleniumDebug = debug
         print("[Wenxin] 开始模拟登录\n")
@@ -105,6 +105,13 @@ class WenXinBot:
             options.add_argument('log-level=3')
             # options.binary_location = '98.0.4758.102_chrome_installer.exe'
             self.driver = webdriver.Chrome(executable_path='chromedriver.exe', options=options)
+            self.driver.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
+            "source": """
+                Object.defineProperty(navigator, 'webdriver', {
+                get: () => undefined
+                })
+            """
+            })
             self.driver.get(url)
             time.sleep(5)
             self.driver.delete_all_cookies()
